@@ -11,4 +11,4 @@
 DD-plot, Journal of the American Statistical Association 107(498): 737 - 753.
 */
 
-TPoint PolynomialLearnCV(TDMatrix input, unsigned numClass1, unsigned numClass2, unsigned int maxDegree, unsigned int chunkNumber, int *degree, int *axis);
+TPoint PolynomialLearnCV(TDMatrix input, int numClass1, int numClass2, int maxDegree, int chunkNumber, int *degree, int *axis);
